@@ -20,6 +20,8 @@ pub enum BitMapBackendError {
     InvalidBuffer,
     /// Some IO error occurs while the bitmap maniuplation
     IOError(std::io::Error),
+    #[cfg(all(feature = "gif", not(target_arch = "wasm32"), feature = "image"))]
+    GifEncodingError(gif::EncodingError),
     #[cfg(all(not(target_arch = "wasm32"), feature = "image"))]
     /// Image encoding error
     ImageError(ImageError),
@@ -45,7 +47,7 @@ fn blend(prev: &mut u8, new: u8, a: u64) {
 #[cfg(all(feature = "gif", not(target_arch = "wasm32"), feature = "image"))]
 mod gif_support {
     use super::*;
-    use gif::{Encoder as GifEncoder, Frame as GifFrame, Repeat, SetParameter};
+    use gif::{Encoder as GifEncoder, Frame as GifFrame, Repeat};
     use std::fs::File;
 
     pub(super) struct GifFile {
@@ -67,11 +69,11 @@ mod gif_support {
                 dim.1 as u16,
                 &[],
             )
-            .map_err(BitMapBackendError::IOError)?;
+            .map_err(BitMapBackendError::GifEncodingError)?;
 
             encoder
-                .set(Repeat::Infinite)
-                .map_err(BitMapBackendError::IOError)?;
+                .set_repeat(Repeat::Infinite)
+                .map_err(BitMapBackendError::GifEncodingError)?;
 
             Ok(Self {
                 encoder,
@@ -89,7 +91,7 @@ mod gif_support {
 
             self.encoder
                 .write_frame(&frame)
-                .map_err(BitMapBackendError::IOError)?;
+                .map_err(BitMapBackendError::GifEncodingError)?;
 
             Ok(())
         }
@@ -864,7 +866,7 @@ impl<'a, P: PixelFormat> DrawingBackend for BitMapBackend<'a, P> {
             Target::File(path) => {
                 if let Some(img) = BorrowedImage::from_raw(w, h, self.buffer.borrow_buffer()) {
                     img.save(&path).map_err(|x| {
-                        DrawingErrorKind::DrawingError(BitMapBackendError::IOError(x))
+                        DrawingErrorKind::DrawingError(BitMapBackendError::ImageError(x))
                     })?;
                     self.saved = true;
                     Ok(())
@@ -1009,6 +1011,7 @@ impl<P: PixelFormat> Drop for BitMapBackend<'_, P> {
 #[test]
 fn test_bitmap_backend() {
     use plotters::prelude::*;
+
     let mut buffer = vec![0; 10 * 10 * 3];
 
     {
@@ -1411,7 +1414,7 @@ mod test {
             let mut chart = ChartBuilder::on(&root)
                 .caption("This is a test", ("sans-serif", 20))
                 .set_all_label_area_size(40)
-                .build_ranged(0..10, 0..10)
+                .build_cartesian_2d(0..10, 0..10)
                 .unwrap();
 
             chart
@@ -1447,7 +1450,7 @@ mod test {
             let mut chart = ChartBuilder::on(&root)
                 .caption("All anchor point positions", ("sans-serif", 20))
                 .set_all_label_area_size(40)
-                .build_ranged(0..100, 0..50)
+                .build_cartesian_2d(0..100, 0..50)
                 .unwrap();
 
             chart
@@ -1532,7 +1535,7 @@ mod test {
             let mut chart = ChartBuilder::on(&root)
                 .caption("All series label positions", ("sans-serif", 20))
                 .set_all_label_area_size(40)
-                .build_ranged(0..50, 0..50)
+                .build_cartesian_2d(0..50, 0..50)
                 .unwrap();
 
             chart
